/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.uinfo.salix;

import java.util.Collection;

import org.dive4elements.river.artifacts.common.ExportContextCSV;
import org.dive4elements.river.artifacts.common.IExportContext;
import org.dive4elements.river.artifacts.common.ResultRow;
import org.dive4elements.river.artifacts.sinfo.util.RiverInfo;
import org.dive4elements.river.artifacts.uinfo.common.UInfoResultType;

/**
 * @author Domenico Nardi Tironi
 */
final class SalixLineCalculationHistoricalResult extends SalixLineCalculationNoScenarioResult {

    private static final long serialVersionUID = 1L;

    public SalixLineCalculationHistoricalResult(final String label, final Collection<ResultRow> rows) {
        super(label, rows);
    }

    @Override
    public void writeCSVHeader(final ExportContextCSV exportContextCSV, final RiverInfo river) {

        final Collection<String> header = super.writeNoScenarioHeader(exportContextCSV);

        header.add(exportContextCSV.formatCsvHeader(UInfoResultType.salixlinehist));
        header.add(exportContextCSV.formatCsvHeader(UInfoResultType.salix_line_scenario_dwspl));

        exportContextCSV.writeCSVLine(header.toArray(new String[header.size()]));
    }

    @Override
    protected void writeCSVResultMetadata(final ExportContextCSV exportContextCSV) {
        writeHistoricalViewCSVMetadata(exportContextCSV);
        exportContextCSV.writeBlankLine();
    }

    @Override
    protected String[] formatRow(final IExportContext context, final ResultRow row) {

        final Collection<String> lines = super.getNoScenarioFormat(row, context);

        if (context instanceof ExportContextCSV) { // enum gespart - pdf-export hat ja nur die drei spalten
            lines.add(context.formatRowValue(row, UInfoResultType.salixlinehist));
            lines.add(context.formatRowValue(row, UInfoResultType.salix_line_scenario_dwspl));

        }
        return lines.toArray(new String[lines.size()]);
    }

    private void writeHistoricalViewCSVMetadata(final ExportContextCSV exportContextCSV) {
        final String main = "uinfo.export.csv.meta.header.salix.historical";
        // "##Historische Betrachtung"
        exportContextCSV.writeCSVMetaEntry(main);

        final String mainSub = "uinfo.export.csv.meta.header.salix";
        // "# Teilabschnitt: "
        exportContextCSV.writeCSVMetaEntry(mainSub + ".teilabschnitt");

        // "# Historischer Zeitpunkt: "
        exportContextCSV.writeCSVMetaEntry(main + ".zeitpunkt");
    }
}